@@ -12,11 +12,6 @@ pub struct ActorError {
     msg: String,
 }
 
-pub const SYS_FORBIDDEN: ExitCode = ExitCode::new(8);
-pub const SYS_ILLEGAL_ACTOR: ExitCode = ExitCode::new(9);
-pub const SYS_ILLEGAL_ARGUMENT: ExitCode = ExitCode::new(10);
-pub const USR_PLACEHOLDER: ExitCode = ExitCode::new(1000);
-
 impl ActorError {
     pub fn new(exit_code: ExitCode, msg: String) -> Self {
         Self { exit_code, msg }
@@ -29,7 +24,7 @@ impl ActorError {
 
     /// Returns true when the exit code is `Ok`.
     pub fn is_ok(&self) -> bool {
-        self.exit_code == ExitCode::OK
+        self.exit_code == ExitCode::Ok
     }
 
     /// Error message of the actor error.
@@ -45,12 +40,16 @@ impl ActorError {
 }
 
 // TODO former EncodingError
-impl From<fvm_ipld_encoding::Error> for ActorError {
-    fn from(e: fvm_ipld_encoding::Error) -> Self {
-        Self {
-            exit_code: ExitCode::USR_SERIALIZATION,
-            msg: e.to_string(),
-        }
+impl From<fvm_shared::encoding::Error> for ActorError {
+    fn from(e: fvm_shared::encoding::Error) -> Self {
+        Self { exit_code: ExitCode::ErrSerialization, msg: e.to_string() }
+    }
+}
+
+// TODO former CborError
+impl From<fvm_shared::encoding::error::Error> for ActorError {
+    fn from(e: fvm_shared::encoding::error::Error) -> Self {
+        Self { exit_code: ExitCode::ErrSerialization, msg: e.to_string() }
     }
 }
 
@@ -64,8 +63,8 @@ impl From<fvm_sdk::error::ActorDeleteError> for ActorError {
             // FIXME: These shouldn't be "system" errors, but we're trying to match existing
             // behavior here.
             exit_code: match e {
-                BeneficiaryIsSelf => SYS_ILLEGAL_ACTOR,
-                BeneficiaryDoesNotExist => SYS_ILLEGAL_ARGUMENT,
+                BeneficiaryIsSelf => ExitCode::SysErrIllegalActor,
+                BeneficiaryDoesNotExist => ExitCode::SysErrIllegalArgument,
             },
             msg: e.to_string(),
         }
@@ -80,7 +79,7 @@ impl From<fvm_sdk::error::NoStateError> for ActorError {
         Self {
             // FIXME: These shouldn't be "system" errors, but we're trying to match existing
             // behavior here.
-            exit_code: SYS_ILLEGAL_ACTOR,
+            exit_code: ExitCode::SysErrIllegalActor,
             msg: e.to_string(),
         }
     }
@@ -90,10 +89,7 @@ impl From<fvm_sdk::error::NoStateError> for ActorError {
 /// to ActorErrors. This facilitates propagation.
 impl From<ExitCode> for ActorError {
     fn from(e: ExitCode) -> Self {
-        ActorError {
-            exit_code: e,
-            msg: "".to_string(),
-        }
+        ActorError { exit_code: e, msg: "".to_string() }
     }
 }
 
