@@ -2,11 +2,10 @@
 // SPDX-License-Identifier: Apache-2.0, MIT
 
 use fil_actors_runtime::Set;
-use fvm_ipld_blockstore::MemoryBlockstore;
 
 #[test]
 fn put() {
-    let store = MemoryBlockstore::new();
+    let store = fvm_shared::blockstore::MemoryBlockstore::new();
     let mut set = Set::new(&store);
 
     let key = "test".as_bytes();
@@ -18,7 +17,7 @@ fn put() {
 
 #[test]
 fn collect_keys() {
-    let store = MemoryBlockstore::new();
+    let store = fvm_shared::blockstore::MemoryBlockstore::new();
     let mut set = Set::new(&store);
 
     set.put("0".into()).unwrap();
@@ -34,7 +33,7 @@ fn collect_keys() {
 
 #[test]
 fn delete() {
-    let store = MemoryBlockstore::new();
+    let store = fvm_shared::blockstore::MemoryBlockstore::new();
     let mut set = Set::new(&store);
 
     let key = "0".as_bytes();
